@@ -744,6 +744,15 @@ class DelayedArgument(LazyEvaluation):
         except TooLazy:
             return compute_range
 
+    @handler.register('env', final=True)
+    def env(self, name: str) -> bytes:
+        """
+        The final modifier `env:name` returns the UTF8-encoded value of the environment variable
+        with the given name.
+        """
+        import os
+        return os.environ[name]
+
     @handler.register('pos')
     def pos(self, regex: ByteString, occurrence: int = 0) -> int:
         """
@@ -781,6 +790,15 @@ class DelayedArgument(LazyEvaluation):
 
         return _pos
 
+    @handler.register('rx')
+    def rx(self, str: bytes) -> bytes:
+        """
+        The handler `rx:str` returns a regular expression which matches the exact string
+        sequence given by `str`, with special regular expression control characters escaped.
+        """
+        import re
+        return re.escape(str)
+
     @handler.register('c', 'copy', final=True)
     def copy(self, region: str) -> bytes:
         """
@@ -1271,16 +1289,6 @@ class DelayedRegexpArgument(DelayedArgument):
         pattern[1::2] = [yara_range(b) for b in pattern[1::2]]
         return B''.join(pattern)
 
-    @handler.register('escape')
-    def escape(self, str: bytes) -> bytes:
-        """
-        The handler `escape:str` returns a regular expression which matches the exact
-        string sequence given by `str`, with special regular expression control characters
-        escaped.
-        """
-        import re
-        return re.escape(str)
-
 
 class DelayedNumberArgument(DelayedArgument):
     """
