@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 from itertools import cycle
 
-from refinery.units.crypto.cipher import arg, StreamCipherUnit
+from refinery.units.crypto.cipher import Arg, StreamCipherUnit
 
 
 class rc4mod(StreamCipherUnit):
@@ -12,7 +12,7 @@ class rc4mod(StreamCipherUnit):
 
     def __init__(
         self, key, stateful=False, *,
-        size: arg.number('-t', help='Table size, {default} by default.', bound=(1, None)) = 0x100
+        size: Arg.Number('-t', help='Table size, {default} by default.', bound=(1, None)) = 0x100
     ):
         super().__init__(key=key, stateful=stateful, size=size)
 
