@@ -3,8 +3,6 @@
 """
 Implements password hashing algorithms.
 """
-import hashlib
-
 from refinery.units.crypto.hash import HashUnit
 
 
@@ -13,4 +11,5 @@ class ntlm(HashUnit):
     Returns the Windows NTLM hash of the input.
     """
     def _algorithm(self, data: bytes) -> bytes:
-        return hashlib.new('md4', data.decode(self.codec).encode("utf-16le")).digest()
+        from Crypto.Hash import MD4
+        return MD4.new(data.decode(self.codec).encode('utf-16le'))
