@@ -7,9 +7,4 @@ from refinery.units.obfuscation import Deobfuscator
 
 class deob_vba_comments(Deobfuscator):
     def deobfuscate(self, data):
-        return re.sub(
-            R"^\s{0,20}(?:'|rem\b|dim\b).*$\n\r?",
-            '',
-            data,
-            flags=re.MULTILINE | re.IGNORECASE
-        )
+        return re.sub(R"(?im)^\s{0,20}(?:'|rem\b|dim\b).*(?:\Z|$\n\r?)", '', data)
